#!/usr/bin/perl

#######################################################################
#
#	WBM spool files processing:
#
#	Written by Dr. A. Prusevich (alex.proussevitch@unh.edu)
#
#	July 2021	Adopted from a stand alone script
#
#######################################################################

use strict;
use File::Basename;
use Getopt::Long;

#######################################################################
#############   Process and check command line inputs   ###############

my ($help,$quiet,$nc,$forks) = (0,0,0,8);
			# Get command line options
usage() if !GetOptions( 'h'=>\$help, 'q'=>\$quiet, 'nc'=>\$nc, 'f=i'=>\$forks ) or $help;

#######################################################################
#############   Build Spool   #########################################

my @list = (
#   "/wbm/utilities//build_spool.pl -v -f _FORKS_ -sd 1999-01-01 -ed 2020-12-31    -spDir /wbm/spool/ -mt /wbm/wbm_output/ipswich_test.MT.csv /wbm/data/Merit_30sec_Ipswich.asc metdata_prate_d",
   "/wbm/utilities//build_spool.pl -v -f _FORKS_ -sd 1999-01-01 -ed 2020-12-31    -spDir /wbm/spool/ -mt /wbm/wbm_output/ipswich_test.MT.csv /wbm/data/Merit_30sec_Ipswich.asc metdata_air.2m_d"
);
map(s/_FORKS_/$forks/,	@list);		# Set forks
map(s/ -v / -v  -nc /,	@list) if $nc;	# Add nc output,  if needed
map(s/ -v //,		@list) if $quiet;	# Remove verbose, if needed
map(s/\s+/ /g,		@list);		# Remove extra spaces

print "\n" unless $quiet;

foreach my $cmd (@list) {
  system "$cmd";
}
print "\nAll Done!\n\n" unless $quiet;

exit;

#######################################################################
######################  Functions  ####################################

sub usage
{
  my $app_name = basename($0);
  print <<EOF;

Usage:
	$app_name [-h] [-q] [-nc] [-f FORKS]

This code pre-builds spool files for a WBM run.

Options:

h	Display this help.
q	Quiet mode.
f	Number of forks to use. Default is $forks.
nc	Build additional NetCDF copy of spool binary data.

Example:
$app_name -q -f 24

EOF
  exit;
}

